@@ -8,10 +8,10 @@ try:
 except ImportError:
 	pass
 
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 __author__ = 'Karl Bedrich'
 __email__ = 'karl@bedrich.de'
-__url__ = 'http://pypi.python.org/pypi/AppBase/'
+__url__ = 'https://pypi.python.org/pypi/fancytools'
 __license__ = 'GPLv3'
 __description__ = '...'#TODO
 __depencies__= [
